==> supysonic_0.5.0+ds.orig.tar.xz: supysonic-0.5.0/supysonic/managers/user.py <==
# coding: utf-8
#
# This file is part of Supysonic.
# Supysonic is a Python implementation of the Subsonic server API.
#
# Copyright (C) 2013-2018 Alban 'spl0k' Féron
#                    2017 Óscar García Amor
#
# Distributed under terms of the GNU AGPLv3 license.

import hashlib
import random
import string
import uuid

from pony.orm import ObjectNotFound

from ..db import User


class UserManager:
    @staticmethod
    def get(uid):
        if isinstance(uid, uuid.UUID):
            pass
        elif isinstance(uid, str):
            uid = uuid.UUID(uid)
        else:
            raise ValueError("Invalid user id")

        return User[uid]

    @staticmethod
    def add(name, password, mail, admin):
        if User.exists(name=name):
            raise ValueError("User '{}' exists".format(name))

        crypt, salt = UserManager.__encrypt_password(password)

        user = User(name=name, mail=mail, password=crypt, salt=salt, admin=admin)

        return user

    @staticmethod
    def delete(uid):
        user = UserManager.get(uid)
        user.delete()

    @staticmethod
    def delete_by_name(name):
        user = User.get(name=name)
        if user is None:
            raise ObjectNotFound(User)
        user.delete()

    @staticmethod
    def try_auth(name, password):
        user = User.get(name=name)
        if user is None:
            return None
        elif UserManager.__encrypt_password(password, user.salt)[0] != user.password:
            return None
        else:
            return user

    @staticmethod
    def change_password(uid, old_pass, new_pass):
        user = UserManager.get(uid)
        if UserManager.__encrypt_password(old_pass, user.salt)[0] != user.password:
            raise ValueError("Wrong password")

        user.password = UserManager.__encrypt_password(new_pass, user.salt)[0]

    @staticmethod
    def change_password2(name, new_pass):
        user = User.get(name=name)
        if user is None:
            raise ObjectNotFound(User)

        user.password = UserManager.__encrypt_password(new_pass, user.salt)[0]

    @staticmethod
    def __encrypt_password(password, salt=None):
        if salt is None:
            salt = "".join(random.choice(string.printable.strip()) for _ in range(6))
        return (
            hashlib.sha1(salt.encode("utf-8") + password.encode("utf-8")).hexdigest(),
            salt,
        )

==> supysonic_0.6.2+ds.orig.tar.xz: supysonic-0.6.2/supysonic/managers/user.py <==
# This file is part of Supysonic.
# Supysonic is a Python implementation of the Subsonic server API.
#
# Copyright (C) 2013-2020 Alban 'spl0k' Féron
#                    2017 Óscar García Amor
#
# Distributed under terms of the GNU AGPLv3 license.

import hashlib
import random
import string
import uuid

from pony.orm import ObjectNotFound

from ..db import User


class UserManager:
    @staticmethod
    def get(uid):
        if isinstance(uid, uuid.UUID):
            pass
        elif isinstance(uid, str):
            uid = uuid.UUID(uid)
        else:
            raise TypeError("Invalid user id")

        return User[uid]

    @staticmethod
    def add(name, password, **kwargs):
        if User.exists(name=name):
            raise ValueError("User '{}' exists".format(name))

        crypt, salt = UserManager.__encrypt_password(password)
        return User(name=name, password=crypt, salt=salt, **kwargs)

    @staticmethod
    def delete(uid):
        user = UserManager.get(uid)
        user.delete()

    @staticmethod
    def delete_by_name(name):
        user = User.get(name=name)
        if user is None:
            raise ObjectNotFound(User)
        user.delete()

    @staticmethod
    def try_auth(name, password):
        user = User.get(name=name)
        if user is None:
            return None
        elif UserManager.__encrypt_password(password, user.salt)[0] != user.password:
            return None
        else:
            return user

    @staticmethod
    def change_password(uid, old_pass, new_pass):
        user = UserManager.get(uid)
        if UserManager.__encrypt_password(old_pass, user.salt)[0] != user.password:
            raise ValueError("Wrong password")

        user.password = UserManager.__encrypt_password(new_pass, user.salt)[0]

    @staticmethod
    def change_password2(name_or_user, new_pass):
        if isinstance(name_or_user, User):
            user = name_or_user
        elif isinstance(name_or_user, str):
            user = User.get(name=name_or_user)
            if user is None:
                raise ObjectNotFound(User)
        else:
            raise TypeError("Requires a User instance or a user name (string)")

        user.password = UserManager.__encrypt_password(new_pass, user.salt)[0]

    @staticmethod
    def __encrypt_password(password, salt=None):
        if salt is None:
            salt = "".join(random.choice(string.printable.strip()) for _ in range(6))
        return (
            hashlib.sha1(salt.encode("utf-8") + password.encode("utf-8")).hexdigest(),
            salt,
        )
